@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '1.27'; # VERSION
+our $DATE = '2015-09-06'; # DATE
+our $VERSION = '1.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -548,7 +548,7 @@ sub do_completion {
             # complete subcommand name
             if ($self->subcommands &&
                     $subcommand_name_from ne '--cmd' &&
-                         $args{type} eq 'arg' && $args{argpos}==0) {
+                         $type eq 'arg' && $args{argpos}==0) {
                 require Complete::Util;
                 return Complete::Util::complete_array_elem(
                     array => [keys %{ $self->list_subcommands }],
@@ -1398,7 +1398,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.27 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-08-17.
+This document describes version 1.28 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-09-06.
 
 =head1 DESCRIPTION
 
